Session and Observation Specification for a Single LWA Station
==============================================================

DP-Based Stations
-----------------
.. automodule:: lsl.common.sdf
   :members:

ADP-Based Stations
------------------
.. automodule:: lsl.common.sdfADP
   :members:

